# filter out bogus auto-requires
%global __requires_exclude pear\\(.*\\)

Name:           codelite
Version:        17.12.1
Release:        %mkrel 2
Summary:        A powerful open-source, cross platform C/C++/PHP IDE
License:        GPLv2+
Group:          Development/Tools
Url:            https://codelite.org/
Source0:        https://github.com/eranif/codelite/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        extra-deps.tar.xz
Patch0:         codelite-remove-bundled-wxsqlite.patch
Patch1:         codelite-remove-bundled-yaml-cpp.patch
Patch2:         codelite-disable-stripping.patch
Patch3:         codelite-default-no-check-for-updates.patch
Patch11:        codelite-17.12.1-mga-set-proper-libdir.patch
Patch12:        codelite-17.12.1-mga-set-proper-mandir.patch
Patch101:       0001-Fix-HiDPI-install-locations.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  ccache
BuildRequires:  clang-devel
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  lldb-devel
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(wxsqlite3)
BuildRequires:  pkgconfig(yaml-cpp)
BuildRequires:  wxgtk-devel
BuildRequires:  glibc-static-devel
Recommends:     gcc
Recommends:     xterm

%description
CodeLite uses a sophisticated, yet intuitive interface which allows
users to easily create, build and debug complex projects.

It provides built-in support for GCC/Clang/VC++ compilers and debugging
using GDB.

%prep
%autosetup -p1 -a1

# Make sure we don't build against bundled (wx)sqlite3 and yaml-cpp
rm -rf sdk/wxsqlite3
rm -rf submodules/yaml-cpp

# Make sure stripping is disabled
sed -i -e '/CMAKE_INSTALL_DO_STRIP/s/TRUE/FALSE/g' -e '/CMAKE_INSTALL_DO_STRIP/s/ON/OFF/g' CMakeLists.txt

%build
%cmake -GNinja \
       -DCL_INSTALL_LIBDIR=%{_lib} \
       -DENABLE_STATIC=OFF \
       -DENABLE_CLANG=1 \
       -DENABLE_LLDB=1
%cmake_build

%install
%cmake_install

# we do not want devel files
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_libdir}/cmake
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.pc' -delete

# python shebangs
%py3_shebang_fix %{buildroot}%{_bindir}

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS
%license LICENSE COPYING
%{_bindir}/codelite*
%{_bindir}/ctagsd*
%{_bindir}/CxxLocalVariables
%{_bindir}/cc-wrapper
%{_bindir}/convert_hf_to_gguf.py
%{_bindir}/llama-cli
%{_datadir}/codelite/
%{_datadir}/applications/codelite.desktop
%{_datadir}/applications/codelite-url-handler.desktop
%{_iconsdir}/hicolor/*/apps/codelite.png
%{_metainfodir}/org.codelite.codelite.metainfo.xml
%{_libdir}/codelite/
%{_mandir}/man1/codelite*.1*


%changelog
* Sat Oct 12 2024 daviddavid <daviddavid> 17.12.1-2.mga10
+ Revision: 2105116
- use system yaml-cpp

* Fri Oct 11 2024 daviddavid <daviddavid> 17.12.1-1.mga10
+ Revision: 2104986
- new version: 17.12.1

* Thu Feb 23 2023 daviddavid <daviddavid> 17.1.0-2.mga9
+ Revision: 1945176
- re-enable spellchecker plugin
- update also ctags and wxdap deps
- fix manpages path
- patch adding-harfbuzz-headers is no more needed

* Wed Feb 22 2023 kekepower <kekepower> 17.1.0-1.mga9
+ Revision: 1944678
- Update to version 17.1.0
- Rediff patches for new release
- Add new patch to set proper libdir

* Sun Jan 29 2023 wally <wally> 16.7.0-2.mga9
+ Revision: 1936865
- fix HiDPI icon install locations

* Tue Dec 13 2022 kekepower <kekepower> 16.7.0-1.mga9
+ Revision: 1921658
- Update to version 16.7.0

* Fri Oct 21 2022 kekepower <kekepower> 16.5.0-1.mga9
+ Revision: 1898316
- Update to version 16.5.0

* Fri Sep 23 2022 kekepower <kekepower> 16.4.0-2.mga9
+ Revision: 1891723
- Update to version 16.4.0

* Thu Sep 22 2022 tv <tv> 16.3.0-2.mga9
+ Revision: 1891472
- Rebuild for llvm-15

* Sat Sep 17 2022 kekepower <kekepower> 16.3.0-1.mga9
+ Revision: 1889584
- Update to version 16.3.0
- Rediff Patch3: codelite-default-no-check-for-updates.patch
- Update to version 16.1.0

* Fri Jul 15 2022 wally <wally> 16.0.0-1.mga9
+ Revision: 1869080
- new version 16.0.0
- rebuild for wxgtk 3.1.7

* Sat Apr 16 2022 wally <wally> 15.0.11-1.mga9
+ Revision: 1850749
- rebuild for wxgtk 3.1.6
+ tv <tv>
- Rebuild for llvm-14
+ kekepower <kekepower>
- Update to version 15.0.11

* Sat Jan 15 2022 wally <wally> 15.0.8-2.mga9
+ Revision: 1768483
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()
- make sure stripping is disabled

* Sun Jan 02 2022 wally <wally> 15.0.8-1.mga9
+ Revision: 1766126
- new version 15.0.8
- disable spellchecker plugin for now because of build issues
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error
+ tv <tv>
- Rebuild for llvm 13.0

* Tue Mar 02 2021 neoclust <neoclust> 14.0-5.mga9
+ Revision: 1695896
- Rebuild against new clang

* Fri Jan 01 2021 wally <wally> 14.0-4.mga8
+ Revision: 1667692
- rebuild for wxgtk pre 3.1.5 snapshot

* Thu Nov 26 2020 tv <tv> 14.0-3.mga8
+ Revision: 1649620
- rebuild for llvm/clang 11.0

* Sun Aug 16 2020 wally <wally> 14.0-2.mga8
+ Revision: 1614330
- rebuild for new wxgtk 3.1.4

* Mon Apr 06 2020 kekepower <kekepower> 14.0-1.mga8
+ Revision: 1565332
- Update to version 14.0

* Sun Mar 22 2020 tv <tv> 13.0-3.mga8
+ Revision: 1558878
- rebuild for llvm-10.0.0

* Tue Feb 18 2020 umeabot <umeabot> 13.0-2.mga8
+ Revision: 1541821
- Mageia 8 Mass Rebuild

* Thu Jan 02 2020 wally <wally> 13.0-1.mga8
+ Revision: 1475487
- new version 13.0
- build with new cmake macros
- rebuild for wxgtk 3.1.3

* Tue Sep 17 2019 tv <tv> 12.0-9.mga8
+ Revision: 1443215
- disable %%_python_bytecompile_extra
- rebuild for llvm-9.0

* Tue Aug 20 2019 daviddavid <daviddavid> 12.0-8.mga8
+ Revision: 1430662
- add patch to adding harfbuzz headers in FindGTK3.cmake

* Thu Jul 18 2019 wally <wally> 12.0-7.mga8
+ Revision: 1422561
- rebuild with gtk3 enabled wxgtk 3.1.2
- add patch to build against correct wxsqlite libs

* Sun Apr 21 2019 daviddavid <daviddavid> 12.0-6.mga7
+ Revision: 1394156
- rebuild for new wxsqlite3 4.4.2

* Mon Apr 15 2019 akien <akien> 12.0-5.mga7
+ Revision: 1390803
- Rebuild for llvm 8.0.0

* Fri Nov 23 2018 daviddavid <daviddavid> 12.0-4.mga7
+ Revision: 1333469
- rebuild for new hunspell 1.7.0

* Thu Sep 27 2018 tv <tv> 12.0-3.mga7
+ Revision: 1308215
- rebuild for llvm 7.0

* Sun Sep 23 2018 umeabot <umeabot> 12.0-2.mga7
+ Revision: 1296662
- Mageia 7 Mass Rebuild

* Tue Apr 24 2018 daviddavid <daviddavid> 12.0-1.mga7
+ Revision: 1222101
- new version: 12.0
- rename and rediff P0, P1 and P3

* Thu Apr 12 2018 tv <tv> 9.2-10.mga7
+ Revision: 1217694
- rebuild with llvm/clang 6.0

* Tue Nov 21 2017 tv <tv> 9.2-8.mga7
+ Revision: 1178128
- rebuild for llvm/clang 5

* Thu Sep 21 2017 tv <tv> 9.2-7.mga7
+ Revision: 1156932
- rebuild with llvm-4.0 in core/release

* Sun Aug 06 2017 daviddavid <daviddavid> 9.2-6.mga7
+ Revision: 1137582
- rebuild for new libhunspell 1.6

* Sat Jun 03 2017 akien <akien> 9.2-5.mga6
+ Revision: 1106085
- Rebuild for wxgtk 3.0.3.1

* Wed Mar 29 2017 neoclust <neoclust> 9.2-4.mga6
+ Revision: 1095188
- Rebuild for armv5

* Sat Jan 07 2017 tmb <tmb> 9.2-3.mga6
+ Revision: 1080479
- rebuild with new llvm

* Mon Jan 02 2017 daviddavid <daviddavid> 9.2-2.mga6
+ Revision: 1079613
- rebuild for new wxsqlite3 3.4.1

* Mon Sep 19 2016 akien <akien> 9.2-1.mga6
+ Revision: 1054379
- Version 9.2

* Wed Jul 13 2016 daviddavid <daviddavid> 9.1-4.mga6
+ Revision: 1041893
- rebuild for new lldb 3.8.1

* Thu Jun 02 2016 daviddavid <daviddavid> 9.1-3.mga6
+ Revision: 1020007
- rebuild for wxgtk3.0 built with GTK2

* Thu May 19 2016 akien <akien> 9.1-2.mga6
+ Revision: 1017035
- Don't skip RPATH, needed for plugins
- Enable Clang and LLDB support

* Thu May 19 2016 akien <akien> 9.1-1.mga6
+ Revision: 1016991
- Version 9.1

* Tue Apr 26 2016 daviddavid <daviddavid> 9.0-3.mga6
+ Revision: 1006443
- add patch to fix libhunspell-1.4 detection

* Thu Apr 21 2016 tv <tv> 9.0-2.mga6
+ Revision: 1004204
- rebuid for libhunspell 1.4

* Sun Jan 03 2016 akien <akien> 9.0-1.mga6
+ Revision: 919223
- Version 9.0
- Rediff P1, split sqlite3 linking fix into P4

* Sun Oct 04 2015 akien <akien> 8.1-0.mga6
+ Revision: 886203
- Version 8.1
- Build against wxGTK 3.0
- Unbundle wxsqlite3 and cppcheck

* Wed Oct 15 2014 umeabot <umeabot> 3.5.5375-9.mga5
+ Revision: 740106
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 3.5.5375-8.mga5
+ Revision: 693655
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 3.5.5375-7.mga5
+ Revision: 678465
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.5.5375-6.mga4
+ Revision: 503477
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.5.5375-5.mga3
+ Revision: 347980
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Mar 03 2012 dams <dams> 3.5.5375-4.mga2
+ Revision: 217427
- add category='IDE' in desktop file

* Sat Mar 03 2012 dams <dams> 3.5.5375-3.mga2
+ Revision: 217389
- new version 3.5.5375
- rediff patch
- clean spec file

* Wed Sep 14 2011 fwang <fwang> 2.10.0.4778-3.mga2
+ Revision: 143353
- disable parallel build
- rebuild for new libpng
- fix linkage
- fix build
- new version 2.10.0.4778
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs
- Add BR desktop-file-utils

* Thu Mar 31 2011 ennael <ennael> 2.8.0.4537-2.mga1
+ Revision: 79205
- fix group name (#512)

* Tue Mar 15 2011 jquelin <jquelin> 2.8.0.4537-1.mga1
+ Revision: 71632
- using %%mkrel
+ yuri_myasoedov <yuri_myasoedov>
- Removed prefix and libdir from %%configure, %%mkrel is set to 1
- spec improved according to Mageia RPM packaging policy
- imported package codelite

